@@ -1,4 +1,4 @@
-/*      $Id: xfwm4_shortcuteditor.c,v 1.38.2.2 2005/01/14 11:41:37 pollux Exp $
+/*      $Id: xfwm4_shortcuteditor.c 12448 2005-03-29 12:31:39Z pollux $
  
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -68,39 +68,39 @@ cb_popup_del_menu (GtkWidget *widget, gpointer data)
 
         ti = find_theme_info_by_name (theme_name, keybinding_theme_list);
 
-	if (ti)
-	{
-	    gchar *theme_file = NULL;
+        if (ti)
+        {
+            gchar *theme_file = NULL;
 
-	    theme_file = g_build_filename (ti->path, KEY_SUFFIX, KEYTHEMERC, NULL);
-	    if (unlink (theme_file) != 0)
-	      g_warning ("Unable to remove the theme file !");
-	    g_free (theme_file);
-	}
-	else
-	    g_warning ("Cannot find the keytheme !");
+            theme_file = g_build_filename (ti->path, KEY_SUFFIX, KEYTHEMERC, NULL);
+            if (unlink (theme_file) != 0)
+              g_warning ("Unable to remove the theme file !");
+            g_free (theme_file);
+        }
+        else
+            g_warning ("Cannot find the keytheme !");
 
-	/* refresh list */
-	while (keybinding_theme_list)
-	{
-	    theme_info_free ((ThemeInfo *)keybinding_theme_list->data);
-	    keybinding_theme_list = g_list_next (keybinding_theme_list);
-	}
-	g_list_free (keybinding_theme_list);
-	
-	g_free (current_key_theme);
-	current_key_theme = g_strdup ("Default");
-	keybinding_theme_list = NULL;
-	keybinding_theme_list = read_themes (keybinding_theme_list, itf->treeview2, itf->scrolledwindow2,
-					     KEYBINDING_THEMES, current_key_theme);
-	gtk_widget_set_sensitive (itf->treeview3, FALSE);
-	gtk_widget_set_sensitive (itf->treeview4, FALSE);
-	loadtheme_in_treeview (find_theme_info_by_name ("Default", keybinding_theme_list), itf);
-	
-	/* tell it to the mcs manager */
-	mcs_manager_set_string (itf->mcs_plugin->manager, "Xfwm/KeyThemeName", CHANNEL2, current_key_theme);
-	mcs_manager_notify (itf->mcs_plugin->manager, CHANNEL2);
-	write_options (itf->mcs_plugin);
+        /* refresh list */
+        while (keybinding_theme_list)
+        {
+            theme_info_free ((ThemeInfo *)keybinding_theme_list->data);
+            keybinding_theme_list = g_list_next (keybinding_theme_list);
+        }
+        g_list_free (keybinding_theme_list);
+        
+        g_free (current_key_theme);
+        current_key_theme = g_strdup ("Default");
+        keybinding_theme_list = NULL;
+        keybinding_theme_list = read_themes (keybinding_theme_list, itf->treeview2, itf->scrolledwindow2,
+                                             KEYBINDING_THEMES, current_key_theme);
+        gtk_widget_set_sensitive (itf->treeview3, FALSE);
+        gtk_widget_set_sensitive (itf->treeview4, FALSE);
+        loadtheme_in_treeview (find_theme_info_by_name ("Default", keybinding_theme_list), itf);
+        
+        /* tell it to the mcs manager */
+        mcs_manager_set_string (itf->mcs_plugin->manager, "Xfwm/KeyThemeName", CHANNEL2, current_key_theme);
+        mcs_manager_notify (itf->mcs_plugin->manager, CHANNEL2);
+        write_options (itf->mcs_plugin);
     
         g_free (theme_name);
     }
@@ -239,7 +239,7 @@ cb_popup_menu (GtkTreeView *treeview, GdkEventButton *event, gpointer data)
     if ((event->button == 3) && (event->type == GDK_BUTTON_PRESS))
     {
         GtkTreePath *path;
-	GdkScreen *screen;
+        GdkScreen *screen;
 
         if (gtk_tree_view_get_path_at_pos (treeview, event->x, event->y, &path, NULL, NULL, NULL))
         {
@@ -258,15 +258,15 @@ cb_popup_menu (GtkTreeView *treeview, GdkEventButton *event, gpointer data)
             
             ti = find_theme_info_by_name (theme_name, keybinding_theme_list);
 
-	    if (ti)
-	    {
-	        gtk_tree_selection_unselect_all (selection);
-		gtk_tree_selection_select_path (selection, path);
-	      
-		gtk_widget_set_sensitive (itf->popup_del_menuitem, ti->user_writable);
-	    }
-	    else
-	        g_warning ("Cannot find the keytheme !");
+            if (ti)
+            {
+                gtk_tree_selection_unselect_all (selection);
+                gtk_tree_selection_select_path (selection, path);
+              
+                gtk_widget_set_sensitive (itf->popup_del_menuitem, ti->user_writable);
+            }
+            else
+                g_warning ("Cannot find the keytheme !");
 
             g_free (theme_name);
         }
@@ -276,10 +276,10 @@ cb_popup_menu (GtkTreeView *treeview, GdkEventButton *event, gpointer data)
         }
         
        
-	screen = xfce_gdk_display_locate_monitor_with_pointer (NULL, NULL);
-	gtk_menu_set_screen (GTK_MENU (itf->popup_menu), screen ? screen : gdk_screen_get_default ());
+        screen = xfce_gdk_display_locate_monitor_with_pointer (NULL, NULL);
+        gtk_menu_set_screen (GTK_MENU (itf->popup_menu), screen ? screen : gdk_screen_get_default ());
         gtk_menu_popup (GTK_MENU (itf->popup_menu), NULL, NULL, NULL, NULL,
-			event->button, gtk_get_current_event_time());
+                        event->button, gtk_get_current_event_time());
         return TRUE;
     }
 
@@ -292,6 +292,33 @@ cb_popup_menu (GtkTreeView *treeview, GdkEventButton *event, gpointer data)
 void
 loadtheme_in_treeview (ThemeInfo *ti, gpointer data)
 {
+    const gchar *shortcut_options_list [] = {"close_window_key", "maximize_window_key", "maximize_vert_key", 
+					     "maximize_horiz_key", "hide_window_key", "shade_window_key",
+					     "stick_window_key", "cycle_windows_key", "move_window_up_key", 
+					     "move_window_down_key", "move_window_left_key", "move_window_right_key",
+					     "resize_window_up_key", "resize_window_down_key", "resize_window_left_key",
+					     "resize_window_right_key", "raise_window_key", "lower_window_key",
+					     "fullscreen_key", "up_workspace_key", "down_workspace_key",
+					     "left_workspace_key", "right_workspace_key", "next_workspace_key",
+					     "prev_workspace_key", "add_workspace_key", "del_workspace_key",
+					     "move_window_next_workspace_key", "move_window_prev_workspace_key",
+					     "move_window_up_workspace_key", "move_window_down_workspace_key", 
+					     "move_window_left_workspace_key", "move_window_right_workspace_key",
+					     "show_desktop_key", NULL};
+
+    const gchar *shortcut_name_list [] ={N_("Close window"), N_("Maximize window"), _("Maximize window vertically"),
+					 N_("Maximize window horizontally"), N_("Hide window"), N_("Shade window"),
+					 N_("Stick window"), N_("Cycle windows"), N_("Move window up"), N_("Move window down"),
+					 N_("Move window left"), N_("Move window right"), N_("Resize window up"), 
+					 N_("Resize window down"), N_("Resize window left"), N_("Resize window right"),
+					 N_("Raise window"), N_("Lower window"), N_("Toggle fullscreen"), N_("Upper workspace"),
+					 N_("Bottom workspace"), N_("Left workspace"), N_("Right workspace"), N_("Next workspace"),
+					 N_("Previous workspace"), N_("Add workspace"), N_("Delete workspace"), 
+					 N_("Move window to next workspace"), N_("Move window to previous workspace"), 
+					 N_("Move window to upper workspace"), N_("Move window to bottom workspace"), 
+					 N_("Move window to left workspace"), N_("Move window to right workspace"), 
+					 N_( "Show desktop" ), NULL};
+
     Itf *itf = (Itf *) data;
 
     XfceRc *default_rc = NULL;
@@ -319,15 +346,15 @@ loadtheme_in_treeview (ThemeInfo *ti, gpointer data)
     {
         g_free (user_theme_file);
         user_theme_file = g_strdup (default_theme_file);
-	gtk_widget_set_sensitive (itf->treeview3, FALSE);
-	gtk_widget_set_sensitive (itf->treeview4, FALSE);
-	gtk_widget_set_sensitive (itf->del_button, FALSE);
+        gtk_widget_set_sensitive (itf->treeview3, FALSE);
+        gtk_widget_set_sensitive (itf->treeview4, FALSE);
+        gtk_widget_set_sensitive (itf->del_button, FALSE);
     }
     else
     {
-      	gtk_widget_set_sensitive (itf->treeview3, TRUE);
-	gtk_widget_set_sensitive (itf->treeview4, TRUE);
-	gtk_widget_set_sensitive (itf->del_button, TRUE);
+        gtk_widget_set_sensitive (itf->treeview3, TRUE);
+        gtk_widget_set_sensitive (itf->treeview4, TRUE);
+        gtk_widget_set_sensitive (itf->del_button, TRUE);
     }
 
     default_rc = xfce_rc_simple_open (default_theme_file, TRUE);
@@ -344,6 +371,9 @@ loadtheme_in_treeview (ThemeInfo *ti, gpointer data)
     {
         const gchar *entry_value;
         const gchar *fallback_value;
+	int i;
+	gboolean found = FALSE;
+
 
         fallback_value = xfce_rc_read_entry (default_rc, *shortcut, "none");
         entry_value = xfce_rc_read_entry (user_rc, *shortcut, fallback_value);
@@ -354,402 +384,91 @@ loadtheme_in_treeview (ThemeInfo *ti, gpointer data)
             continue;
         }
 
-        if (g_ascii_strcasecmp (*shortcut, "close_window_key") == 0)
-        {
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, _("Close window"), COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "maximize_window_key") == 0)
-        {
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, _("Maximize window"), COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "maximize_vert_key") == 0)
-        {
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, _("Maximize window vertically"), COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "maximize_horiz_key") == 0)
-        {
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, _("Maximize window horizontally"), COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "hide_window_key") == 0)
-        {
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, _("Hide window"), COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "shade_window_key") == 0)
-        {
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, _("Shade window"), COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "stick_window_key") == 0)
-        {
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, _("Stick window"), COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "cycle_windows_key") == 0)
-        {
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, _("Cycle windows"), COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "move_window_up_key") == 0)
-        {
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, _("Move window up"), COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "move_window_down_key") == 0)
-        {
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, _("Move window down"), COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "move_window_left_key") == 0)
-        {
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, _("Move window left"), COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "move_window_right_key") == 0)
-        {
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, _("Move window right"), COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "resize_window_up_key") == 0)
-        {
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, _("Resize window up"), COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "resize_window_down_key") == 0)
-        {
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, _("Resize window down"), COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "resize_window_left_key") == 0)
-        {
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, _("Resize window left"), COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "resize_window_right_key") == 0)
-        {
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, _("Resize window right"), COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "raise_window_key") == 0)
-        {
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, _("Raise window"), COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "lower_window_key") == 0)
-        {
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, _("Lower window"), COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "fullscreen_key") == 0)
-        {
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, _("Toggle fullscreen"), COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "up_workspace_key") == 0)
-        {
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, _("Upper workspace"), COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "down_workspace_key") == 0)
-        {
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, _("Bottom workspace"), COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "left_workspace_key") == 0)
-        {
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, _("Left workspace"), COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "right_workspace_key") == 0)
-        {
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, _("Right workspace"), COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "next_workspace_key") == 0)
-        {
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, _("Next workspace"), COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "prev_workspace_key") == 0)
-        {
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, _("Previous workspace"), COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "add_workspace_key") == 0)
-        {
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, _("Add workspace"), COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "del_workspace_key") == 0)
-        {
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, _("Delete workspace"), COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "workspace_1_key") == 0)
-        {
-	    gchar *text;
+	for (i = 0; !found && shortcut_options_list[i]; i++)
+	{
+	    if (g_ascii_strcasecmp (*shortcut, shortcut_options_list[i]) == 0)
+	    {
+		gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
+		gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, _(shortcut_name_list[i]),
+				   COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
+		found = TRUE;
+	    }
+	}
+
+
+	for (i = 0; !found && i <= 12; i++)
+	{
+	    gchar *option;
+
+	    option = g_strdup_printf ("workspace_%d_key", i);
+	    if (g_ascii_strcasecmp (*shortcut, option) == 0)
+	    {
+		gchar *text;
+
+		text = g_strdup_printf (_("Workspace %d"), i);
+		gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
+		gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, text, 
+				    COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
+		g_free (text);
+
+		found = TRUE;
+	    }
 	    
-	    text = g_strdup_printf (_("Workspace %d"), 1);
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, text, COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-	    g_free (text);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "workspace_2_key") == 0)
-        {
-	    gchar *text;
-	    
-	    text = g_strdup_printf (_("Workspace %d"), 2);
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, text, COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-	    g_free (text);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "workspace_3_key") == 0)
-        {
-	    gchar *text;
-	    
-	    text = g_strdup_printf (_("Workspace %d"), 3);
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, text, COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-	    g_free (text);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "workspace_4_key") == 0)
-        {
-	    gchar *text;
-	    
-	    text = g_strdup_printf (_("Workspace %d"), 4);
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, text, COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-	    g_free (text);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "workspace_5_key") == 0)
-        {
-	    gchar *text;
-	    
-	    text = g_strdup_printf (_("Workspace %d"), 5);
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, text, COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-	    g_free (text);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "workspace_6_key") == 0)
-        {
-	    gchar *text;
-	    
-	    text = g_strdup_printf (_("Workspace %d"), 6);
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, text, COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-	    g_free (text);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "workspace_7_key") == 0)
-        {
-	    gchar *text;
-	    
-	    text = g_strdup_printf (_("Workspace %d"), 7);
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, text, COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-	    g_free (text);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "workspace_8_key") == 0)
-        {
-	    gchar *text;
-	    
-	    text = g_strdup_printf (_("Workspace %d"), 8);
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, text, COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-	    g_free (text);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "workspace_9_key") == 0)
-        {
-	    gchar *text;
-	    
-	    text = g_strdup_printf (_("Workspace %d"), 9);
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, text, COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-	    g_free (text);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "move_window_next_workspace_key") == 0)
-        {
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, _("Move window to next workspace"), COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "move_window_prev_workspace_key") == 0)
-        {
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, _("Move window to previous workspace"), COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "move_window_up_workspace_key") == 0)
-        {
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, _("Move window to upper workspace"), COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "move_window_down_workspace_key") == 0)
-        {
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, _("Move window to bottom workspace"), COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "move_window_left_workspace_key") == 0)
-        {
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, _("Move window to left workspace"), COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "move_window_right_workspace_key") == 0)
-        {
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, _("Move window to right workspace"), COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "move_window_workspace_1_key") == 0)
-        {
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, _("Move window to workspace 1"), COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "move_window_workspace_2_key") == 0)
-        {
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, _("Move window to workspace 2"), COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "move_window_workspace_3_key") == 0)
-        {
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, _("Move window to workspace 3"), COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "move_window_workspace_4_key") == 0)
-        {
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, _("Move window to workspace 4"), COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "move_window_workspace_5_key") == 0)
-        {
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, _("Move window to workspace 5"), COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "move_window_workspace_6_key") == 0)
-        {
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, _("Move window to workspace 6"), COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "move_window_workspace_7_key") == 0)
-        {
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, _("Move window to workspace 7"), COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "move_window_workspace_8_key") == 0)
-        {
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, _("Move window to workspace 8"), COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "move_window_workspace_9_key") == 0)
-        {
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, _("Move window to workspace 9"), COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "shortcut_1_key") == 0)
-        {
-            const gchar *fallback_value2;
-            const gchar *entry_value2;
+	    g_free (option);
+	}
 
-            gtk_list_store_append (GTK_LIST_STORE (model4), &iter);
-            fallback_value2 = xfce_rc_read_entry (default_rc, "shortcut_1_exec", "none");
-            entry_value2 = xfce_rc_read_entry (user_rc, "shortcut_1_exec", fallback_value);
-            gtk_list_store_set (GTK_LIST_STORE (model4), &iter, COLUMN_COMMAND, entry_value2, COLUMN_SHORTCUT, entry_value, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "shortcut_2_key") == 0)
-        {
-            const gchar *fallback_value2;
-            const gchar *entry_value2;
+	for (i = 0; !found && i <= 12; i++)
+	{
+	    gchar *option;
 
-            gtk_list_store_append (GTK_LIST_STORE (model4), &iter);
-            fallback_value2 = xfce_rc_read_entry (default_rc, "shortcut_2_exec", "none");
-            entry_value2 = xfce_rc_read_entry (user_rc, "shortcut_2_exec", fallback_value);
-            gtk_list_store_set (GTK_LIST_STORE (model4), &iter, COLUMN_COMMAND, entry_value2, COLUMN_SHORTCUT, entry_value, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "shortcut_3_key") == 0)
-        {
-            const gchar *fallback_value2;
-            const gchar *entry_value2;
+	    option = g_strdup_printf ("move_window_workspace_%d_key", i);
+	    if (g_ascii_strcasecmp (*shortcut, option) == 0)
+	    {
+	        gchar *text;
 
-            gtk_list_store_append (GTK_LIST_STORE (model4), &iter);
-            fallback_value2 = xfce_rc_read_entry (default_rc, "shortcut_3_exec", "none");
-            entry_value2 = xfce_rc_read_entry (user_rc, "shortcut_3_exec", fallback_value);
-            gtk_list_store_set (GTK_LIST_STORE (model4), &iter, COLUMN_COMMAND, entry_value2, COLUMN_SHORTCUT, entry_value, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "shortcut_4_key") == 0)
-        {
-            const gchar *fallback_value2;
-            const gchar *entry_value2;
+		text = g_strdup_printf (_("Move window to workspace %d"), i);
+	        gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
+		gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, text,
+				    COLUMN_SHORTCUT, entry_value, COLUMN_NAME, *shortcut, -1);
+		g_free (text);
 
-            gtk_list_store_append (GTK_LIST_STORE (model4), &iter);
-            fallback_value2 = xfce_rc_read_entry (default_rc, "shortcut_4_exec", "none");
-            entry_value2 = xfce_rc_read_entry (user_rc, "shortcut_4_exec", fallback_value);
-            gtk_list_store_set (GTK_LIST_STORE (model4), &iter, COLUMN_COMMAND, entry_value2, COLUMN_SHORTCUT, entry_value, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "shortcut_5_key") == 0)
-        {
-            const gchar *fallback_value2;
-            const gchar *entry_value2;
+		found = TRUE;
+	    }
 
-            gtk_list_store_append (GTK_LIST_STORE (model4), &iter);
-            fallback_value2 = xfce_rc_read_entry (default_rc, "shortcut_5_exec", "none");
-            entry_value2 = xfce_rc_read_entry (user_rc, "shortcut_5_exec", fallback_value);
-            gtk_list_store_set (GTK_LIST_STORE (model4), &iter, COLUMN_COMMAND, entry_value2, COLUMN_SHORTCUT, entry_value, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "shortcut_6_key") == 0)
-        {
-            const gchar *fallback_value2;
-            const gchar *entry_value2;
+	    g_free (option);
+	}
 
-            gtk_list_store_append (GTK_LIST_STORE (model4), &iter);
-            fallback_value2 = xfce_rc_read_entry (default_rc, "shortcut_6_exec", "none");
-            entry_value2 = xfce_rc_read_entry (user_rc, "shortcut_6_exec", fallback_value);
-            gtk_list_store_set (GTK_LIST_STORE (model4), &iter, COLUMN_COMMAND, entry_value2, COLUMN_SHORTCUT, entry_value, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "shortcut_7_key") == 0)
-        {
-            const gchar *fallback_value2;
-            const gchar *entry_value2;
+        for (i = 0; !found && i <= 10; i++)
+	{
+	    gchar *option;
 
-            gtk_list_store_append (GTK_LIST_STORE (model4), &iter);
-            fallback_value2 = xfce_rc_read_entry (default_rc, "shortcut_7_exec", "none");
-            entry_value2 = xfce_rc_read_entry (user_rc, "shortcut_7_exec", fallback_value);
-            gtk_list_store_set (GTK_LIST_STORE (model4), &iter, COLUMN_COMMAND, entry_value2, COLUMN_SHORTCUT, entry_value, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "shortcut_8_key") == 0)
-        {
-            const gchar *fallback_value2;
-            const gchar *entry_value2;
+	    option = g_strdup_printf ("shortcut_%d_key", i);
+	    if (g_ascii_strcasecmp (*shortcut, option) == 0)
+	    {
+		const gchar *fallback_value2;
+		const gchar *entry_value2;
+		gchar *shortcut_option;
 
-            gtk_list_store_append (GTK_LIST_STORE (model4), &iter);
-            fallback_value2 = xfce_rc_read_entry (default_rc, "shortcut_8_exec", "none");
-            entry_value2 = xfce_rc_read_entry (user_rc, "shortcut_8_exec", fallback_value);
-            gtk_list_store_set (GTK_LIST_STORE (model4), &iter, COLUMN_COMMAND, entry_value2, COLUMN_SHORTCUT, entry_value, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "shortcut_9_key") == 0)
-        {
-            const gchar *fallback_value2;
-            const gchar *entry_value2;
+		shortcut_option = g_strdup_printf ("shortcut_%d_exec", i);
 
-            gtk_list_store_append (GTK_LIST_STORE (model4), &iter);
-            fallback_value2 = xfce_rc_read_entry (default_rc, "shortcut_9_exec", "none");
-            entry_value2 = xfce_rc_read_entry (user_rc, "shortcut_9_exec", fallback_value);
-            gtk_list_store_set (GTK_LIST_STORE (model4), &iter, COLUMN_COMMAND, entry_value2, COLUMN_SHORTCUT, entry_value, -1);
-        }
-        else if (g_ascii_strcasecmp (*shortcut, "shortcut_10_key") == 0)
-        {
-            const gchar *fallback_value2;
-            const gchar *entry_value2;
+		gtk_list_store_append (GTK_LIST_STORE (model4), &iter);
+		fallback_value2 = xfce_rc_read_entry (default_rc, shortcut_option, "none");
+		entry_value2 = xfce_rc_read_entry (user_rc, shortcut_option, fallback_value);
+		gtk_list_store_set (GTK_LIST_STORE (model4), &iter, COLUMN_COMMAND, entry_value2,
+				    COLUMN_SHORTCUT, entry_value, -1);
+		g_free (shortcut_option);
 
-            gtk_list_store_append (GTK_LIST_STORE (model4), &iter);
-            fallback_value2 = xfce_rc_read_entry (default_rc, "shortcut_10_exec", "none");
-            entry_value2 = xfce_rc_read_entry (user_rc, "shortcut_10_exec", fallback_value);
-            gtk_list_store_set (GTK_LIST_STORE (model4), &iter, COLUMN_COMMAND, entry_value2, COLUMN_SHORTCUT, entry_value, -1);
-        }
-        else
-        {
-            gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
-            gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, *shortcut, COLUMN_SHORTCUT, entry_value, -1);
-        }
+		found = TRUE;
+	    }
+
+	    g_free (option);
+	}
+
+	if (!found)
+	{
+	    gtk_list_store_append (GTK_LIST_STORE (model3), &iter);
+	    gtk_list_store_set (GTK_LIST_STORE (model3), &iter, COLUMN_COMMAND, *shortcut, COLUMN_SHORTCUT, entry_value, -1);
+	}
 
         *shortcut++;
     }
