@@ -1,4 +1,4 @@
-/*      $Id: frame.c 12321 2005-01-28 22:19:12Z olivier $
+/*      $Id: frame.c 16003 2005-06-16 19:18:08Z olivier $
  
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -811,35 +811,52 @@ frameDraw (Client * c, gboolean invalidate_cache, gboolean force_shape_update)
     /* Flag clearance */
     FLAG_UNSET (c->xfwm_flags,  XFWM_FLAG_FIRST_MAP);
 
+    /* Cache mgmt */
+    if (invalidate_cache)
+    {
+        clientClearPixmapCache (c);
+        requires_clearing = TRUE;
+    }
+    else
+    {
+        if (c->pm_cache.previous_width != c->width)
+        {
+            xfwmPixmapFree (&c->pm_cache.pm_title[ACTIVE]);
+            xfwmPixmapFree (&c->pm_cache.pm_title[INACTIVE]);
+            xfwmPixmapFree (&c->pm_cache.pm_sides[SIDE_BOTTOM][ACTIVE]);
+            xfwmPixmapFree (&c->pm_cache.pm_sides[SIDE_BOTTOM][INACTIVE]);
+            c->pm_cache.previous_width = c->width;
+        }
+        if (c->pm_cache.previous_height != c->height)
+        {
+            xfwmPixmapFree (&c->pm_cache.pm_sides[SIDE_LEFT][ACTIVE]);
+            xfwmPixmapFree (&c->pm_cache.pm_sides[SIDE_LEFT][INACTIVE]);
+            xfwmPixmapFree (&c->pm_cache.pm_sides[SIDE_RIGHT][ACTIVE]);
+            xfwmPixmapFree (&c->pm_cache.pm_sides[SIDE_RIGHT][INACTIVE]);
+            c->pm_cache.previous_height = c->height;
+        }
+    }
+
+    /* Corners have no caching and get never resized, we need to update them separately */
+    if (requires_clearing)
+    {
+        XSetWindowBackgroundPixmap (clientGetXDisplay (c),
+            MYWINDOW_XWINDOW (c->corners[CORNER_TOP_LEFT]),
+            screen_info->corners[CORNER_TOP_LEFT][state].pixmap);
+        XSetWindowBackgroundPixmap (clientGetXDisplay (c),
+            MYWINDOW_XWINDOW (c->corners[CORNER_TOP_RIGHT]),
+            screen_info->corners[CORNER_TOP_RIGHT][state].pixmap);
+        XSetWindowBackgroundPixmap (clientGetXDisplay (c),
+            MYWINDOW_XWINDOW (c->corners[CORNER_BOTTOM_LEFT]),
+            screen_info->corners[CORNER_BOTTOM_LEFT][state].pixmap);
+        XSetWindowBackgroundPixmap (clientGetXDisplay (c),
+            MYWINDOW_XWINDOW (c->corners[CORNER_BOTTOM_RIGHT]),
+            screen_info->corners[CORNER_BOTTOM_RIGHT][state].pixmap);
+    }
+
     if (FLAG_TEST (c->xfwm_flags, XFWM_FLAG_HAS_BORDER)
         && !FLAG_TEST (c->flags, CLIENT_FLAG_FULLSCREEN))
     {
-        /* Cache mgmt */
-        if (invalidate_cache)
-        {
-            clientClearPixmapCache (c);
-            requires_clearing = TRUE;
-        }
-        else
-        {
-            if (c->pm_cache.previous_width != c->width)
-            {
-                xfwmPixmapFree (&c->pm_cache.pm_title[ACTIVE]);
-                xfwmPixmapFree (&c->pm_cache.pm_title[INACTIVE]);
-                xfwmPixmapFree (&c->pm_cache.pm_sides[SIDE_BOTTOM][ACTIVE]);
-                xfwmPixmapFree (&c->pm_cache.pm_sides[SIDE_BOTTOM][INACTIVE]);
-                c->pm_cache.previous_width = c->width;
-            }
-            if (c->pm_cache.previous_height != c->height)
-            {
-                xfwmPixmapFree (&c->pm_cache.pm_sides[SIDE_LEFT][ACTIVE]);
-                xfwmPixmapFree (&c->pm_cache.pm_sides[SIDE_LEFT][INACTIVE]);
-                xfwmPixmapFree (&c->pm_cache.pm_sides[SIDE_RIGHT][ACTIVE]);
-                xfwmPixmapFree (&c->pm_cache.pm_sides[SIDE_RIGHT][INACTIVE]);
-                c->pm_cache.previous_height = c->height;
-            }
-        }
-
         /* First, hide the buttons that we don't have... */
         for (i = 0; i < BUTTON_COUNT; i++)
         {
@@ -1007,22 +1024,6 @@ frameDraw (Client * c, gboolean invalidate_cache, gboolean force_shape_update)
                 c->pm_cache.pm_sides[SIDE_RIGHT][state].pixmap);
         }
 
-        if (requires_clearing)
-        {
-            XSetWindowBackgroundPixmap (clientGetXDisplay (c),
-                MYWINDOW_XWINDOW (c->corners[CORNER_TOP_LEFT]),
-                screen_info->corners[CORNER_TOP_LEFT][state].pixmap);
-            XSetWindowBackgroundPixmap (clientGetXDisplay (c),
-                MYWINDOW_XWINDOW (c->corners[CORNER_TOP_RIGHT]),
-                screen_info->corners[CORNER_TOP_RIGHT][state].pixmap);
-            XSetWindowBackgroundPixmap (clientGetXDisplay (c),
-                MYWINDOW_XWINDOW (c->corners[CORNER_BOTTOM_LEFT]),
-                screen_info->corners[CORNER_BOTTOM_LEFT][state].pixmap);
-            XSetWindowBackgroundPixmap (clientGetXDisplay (c),
-                MYWINDOW_XWINDOW (c->corners[CORNER_BOTTOM_RIGHT]),
-                screen_info->corners[CORNER_BOTTOM_RIGHT][state].pixmap);
-        }
-
         if (FLAG_TEST (c->flags, CLIENT_FLAG_SHADED))
         {
             xfwmWindowHide (&c->sides[SIDE_LEFT]);
@@ -1075,24 +1076,27 @@ frameDraw (Client * c, gboolean invalidate_cache, gboolean force_shape_update)
     }
     else
     {
-        xfwmWindowHide (&c->title);
+        if (xfwmWindowVisible (&c->title))
+        {
+            xfwmWindowHide (&c->title);
+        }
         for (i = 0; i < 3; i++)
         {
-            if (MYWINDOW_XWINDOW (c->sides[i]))
+            if (MYWINDOW_XWINDOW (c->sides[i]) && xfwmWindowVisible (&c->sides[i]))
             {
                 xfwmWindowHide (&c->sides[i]);
             }
         }
         for (i = 0; i < 4; i++)
         {
-            if (MYWINDOW_XWINDOW (c->corners[i]))
+            if (MYWINDOW_XWINDOW (c->corners[i]) && xfwmWindowVisible (&c->corners[i]))
             {
                 xfwmWindowHide (&c->corners[i]);
             }
         }
         for (i = 0; i < BUTTON_COUNT; i++)
         {
-            if (MYWINDOW_XWINDOW (c->buttons[i]))
+            if (MYWINDOW_XWINDOW (c->buttons[i]) && xfwmWindowVisible (&c->buttons[i]))
             {
                 xfwmWindowHide (&c->buttons[i]);
             }
