@@ -1,4 +1,5 @@
-/*
+/*      $Id: mypixmap.h 11914 2004-08-22 22:18:50Z olivier $
+ 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
         the Free Software Foundation; either version 2, or (at your option)
@@ -14,31 +15,40 @@
         Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  
         oroborus - (c) 2001 Ken Lynch
-        xfwm4    - (c) 2002-2003 Olivier Fourdan
+        xfwm4    - (c) 2002-2004 Olivier Fourdan
  
  */
 
-#ifndef INC_MYPIXMAP_H
-#define INC_MYPIXMAP_H
-
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #endif
 
 #include <X11/xpm.h>
 #include <glib.h>
+#include "screen.h"
 
-typedef struct
+#ifndef INC_MYPIXMAP_H
+#define INC_MYPIXMAP_H
+
+struct _XfwmPixmap
 {
+    ScreenInfo *screen_info;
     Pixmap pixmap, mask;
     gint width, height;
-}
-MyPixmap;
+};
 
-gboolean myPixmapLoad (Display *, MyPixmap *, gchar *, gchar *,
-                       XpmColorSymbol *, gint);
-void myPixmapCreate (Display *, MyPixmap *, gint, gint);
-void myPixmapInit (MyPixmap *);
-void myPixmapFree (Display *, MyPixmap *);
+gboolean xfwmPixmapLoad   (ScreenInfo *, 
+                           XfwmPixmap *, 
+                           gchar *, 
+                           gchar *,
+                           XpmColorSymbol *, 
+                           gint);
+void xfwmPixmapCreate     (ScreenInfo *, 
+                           XfwmPixmap *, 
+                           gint, 
+                           gint);
+void xfwmPixmapInit       (ScreenInfo *, 
+                           XfwmPixmap *);
+void xfwmPixmapFree       (XfwmPixmap *);
 
 #endif /* INC_MYPIXMAP_H */
