@@ -1,4 +1,5 @@
-/*
+/*      $Id: spinning_cursor.h 11914 2004-08-22 22:18:50Z olivier $
+ 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
         the Free Software Foundation; either version 2, or (at your option)
@@ -13,8 +14,8 @@
         along with this program; if not, write to the Free Software
         Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  
-        Metacity - (c) 2003 Havoc Pennington
-        xfwm4    - (c) 2003 Olivier Fourdan
+        mozilla  - (c) 1998 mozilla.org
+        xfwm4    - (c) 2002-2004 Olivier Fourdan
  
  */
 
@@ -27,6 +28,6 @@
 
 #include <X11/Xlib.h>
 
-Cursor cursorCreateSpinning (Display * dpy, Window window);
+Cursor cursorCreateSpinning (Display * dpy);
 
 #endif /* INC_SPINNING_CURSOR_H */
