@@ -1,4 +1,4 @@
-/*      $Id: workspaces.c,v 1.93.2.4 2005/03/08 09:03:25 olivier Exp $
+/*      $Id: workspaces.c 17585 2005-09-13 20:22:54Z olivier $
  
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -136,7 +136,7 @@ workspaceGetNumber (ScreenInfo *screen_info, int row, int col)
             break;
     }
 
-    n = row*major_length + col;
+    n = (row * major_length) + col;
     return n;
 }
 
@@ -366,11 +366,13 @@ workspaceSwitch (ScreenInfo *screen_info, int new_ws, Client * c2)
     {
         clientSetFocus (new_focus->screen_info, new_focus, myDisplayGetCurrentTime (display_info), NO_FOCUS_FLAG);
     }
+#if 0
     else
     {
         /* If we can't get a window to focus, just pick the one on top */
         clientFocusTop (screen_info, WIN_LAYER_ABOVE_DOCK);
     }
+#endif
 }
 
 void
